#
# spec file for package playerctl
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2017 Dakota Williams <raineforest@raineforest.me>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global majorver 2
%global minorver 0
%global relver 1
%global sover 2
%global libname lib%{name}%{sover}
%global typelibname typelib-1_0-Playerctl-%{majorver}_%{minorver}_%{relver}
Name:           playerctl
Version:        2.0.1
Release:        lp152.1.5
Summary:        MPRIS command-line controller and library for media players
License:        LGPL-3.0-or-later
Group:          Productivity/Multimedia/Other
URL:            https://github.com/acrisci/playerctl
Source0:        https://github.com/acrisci/playerctl/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  meson >= 0.46.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(gobject-2.0) >= 2.38
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.38
BuildRequires:  pkgconfig(gtk-doc)

%description
Playerctl is a command-line utility and library for controlling
media players that implement the MPRIS D-Bus Interface Specification.
Playerctl makes it easy to bind player actions, such as play and pause,
to media keys.

For more advanced users, Playerctl provides an introspectable library
available in your favorite scripting language that allows more detailed
control like the ability to subscribe to media player events or get metadata,
such as artist and title for the playing track.

%package -n %{libname}
Summary:        A library for controlling media players over D-Bus
Group:          System/Libraries

%description -n %{libname}
A library for controlling media players that implement the MPRIS D-Bus
Interface Specification.

%package -n %{typelibname}
Summary:        GObject Introspection interface description for lib%{name}
Group:          System/Libraries

%description -n %{typelibname}
This package provides the GObject Introspection bindings lib%{name},
enabling usage in programming languages that support it.

%package devel
Summary:        Development files for lib%{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
This package provides libraries and headers for developing applications that
use lib%{name}.

%package doc
Summary:        Documentation for lib%{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This package provides HTML documentation for lib%{name}.

%prep
%setup -q

%build
%meson --default-library=shared
%meson_build

%install
%meson_install
# we only want the shared library
rm -f %{buildroot}%{_libdir}/lib%{name}.a

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%doc README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{ext_man}

%files -n %{libname}
%license COPYING
%{_libdir}/lib%{name}.so.%{sover}*

%files -n %{typelibname}
%{_libdir}/girepository-1.0/Playerctl-2.0.typelib

%files devel
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/playerctl.pc
%{_datadir}/gir-1.0/Playerctl-%{majorver}.%{minorver}.gir

%files doc
%{_datadir}/gtk-doc/html/%{name}

%changelog
* Fri Jan 25 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.0.1
  CLI:
  * Add `--ignore-player` flag to ignore specific players (#2)
  * Add `--follow` flag to block and print updated values when
    they change (#37, #98, #101)
  * The `--player` command acts on the first player without
    `--all-players` (breaking) (#54)
  * Accept multiple keys for `metadata [key]` command (#68)
  * `metadata` command has tabular output. (breaking) (#72)
  * Add `--format [fmt]` for metadata formatting (#73)
  * Add `duration()` template formatter for formatting durations
    (#75)
  * Print player name and instance with format strings (#90)
  * Add command to get and set `shuffle` status (#92)
  * Add a command to get and set `loop` status (#99)
  * Add the `open` command to open a URI with the player (#79)
  * Fix some errors with utf8 printing (#80)
  * Skip players from selection when they don't support a
    command (determined by the `can-*` properties)
  * Select all player instances with the `--player` and
    `--ignore-player` command
  * Print help information to stdout (not stderr) when no
    arguments are passed
  Library:
  * add `playerctl_list_players()` to public api for listing
    players (#47)
  * Implement the "seeked" signal on the player (#94)
  * Add the "volume" signal on the player (#95)
  * Deprecate the "play", "pause", and "stopped" signal for a
    single "status" signal (#96)
  * Add the `PlayerctlPlayerManager()` class (#100)
  * Cache and compute the position property (#102)
  * Remove chaining abilities from the library (breaking)
  * Library query functions return `NULL` instead of empty
    string when properties aren't found (breaking)
  * Deprecate `status` property in favor of the
    `playback-status` property as an enum
  * Add library functions for `shuffle` and `loop` status (#92,
    [#99])
  * Deprecate setting volume via the object properties interface
  * Fix the "exit" signal
  * Add properties "can-control", "can-play", "can-pause",
    "can-seek", "can-go-next", "can-go-previous"
  * Add the "source" property to determine the source of the
    player (session or system bus)
  * Change first keyword arg for `playerctl_player_new()` from
    `name` to `player_name` (breaking)
  * Add `playerctl_player_new_for_source()` to select players
    based on the source (session or system bus)
  * Add `playerctl_player_new_from_name()` to create a player
    from a PlayerManager name
  * `playerctl_player_new()` selects an instance of the
    `player_name` if found
  * Add documentation for the entire public library API
  Build:
  * Remove autotools and switch to the meson build system
    (breaking) (#57)
  * Fix various compiler warnings (#97)
  * Remove library version from pkg-config name and add it to
    the so in the standard way (new pkg-config name is just
    `playerctl`).
  version 0.6.1
  * Bugfix: unref of a null player when no players are present
  * Playerctl now searches the system bus for players
  * Parse trackid as a string as a workaround for noncompliant
    players
  * Various meson fixes
  version 0.6.0
  * control multiple players at once by putting commas between
    the names
  * add the --all-players option to control all players at once
  * lib: better cache invalidation strategy for getting
    properties
  * bugfix: Set position in fractional seconds
  * Fix various memory leaks and errors
- Dropped playerctl-0.5.0-fix-parallel-build.patch (no longer
  compatible)
- Switched build to meson
- Added -doc subpackage
* Thu Sep  7 2017 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Drop static-devel package
* Fri Sep  1 2017 raineforest@raineforest.me
- Added comment to indicate lib subpackage requirement by main package
* Thu Aug 31 2017 raineforest@raineforest.me
- Added library subpackages
* Tue Aug 22 2017 raineforest@raineforest.me
- Backport patch from upstream to fix parallel build
  * Added patch:
  - playerctl-0.5.0-fix-parallel-build.patch
* Tue Aug 22 2017 raineforest@raineforest.me
- Initial release
